Function gcd_fixed128
Source pub fn gcd_fixed128(a: I64F64, b: I64F64, dec: u8) -> I64F64
Helper function to calculate the greatest common divisor (GCD) for fixed-point numbers using I64F64.
Arguments
a: The first I64F64 number.
b: The second I64F64 number.
Returns
- An
I64F64 representing the greatest common divisor of a and b.