Function gcd_i64

pub fn gcd_i64(a: i64, b: i64) -> i64
Helper function to calculate the greatest common divisor (GCD) for signed integers.

Arguments

  • a: The first integer.
  • b: The second integer.

Returns

  • An i32 representing the greatest common divisor of a and b.