Function gcd_fixed64
Source pub fn gcd_fixed64(a: I32F32, b: I32F32, dec: u8) -> I32F32
Helper function to calculate the greatest common divisor (GCD) for fixed-point numbers using I32F32.
Arguments
a: The first I32F32 number.
b: The second I32F32 number.
Returns
- An
I32F32 representing the greatest common divisor of a and b.